Validation - Expression vectors
test_expression.RdTest if an object is an expression vector or expression object.
test_expression() is the predicate test, while assert_expression() validates
its input, aborting if it fails the test.
Usage
test_expression(
x,
len = NULL,
n_null = NULL,
n_call = NULL,
n_sym = NULL,
n_literal = NULL,
n_invalid = NULL,
sentinels = NULL,
custom = NULL,
custom_map = NULL
)
assert_expression(
x,
len = NULL,
n_null = NULL,
n_call = NULL,
n_sym = NULL,
n_literal = NULL,
n_invalid = NULL,
sentinels = NULL,
custom = NULL,
custom_map = NULL,
action = "abort",
env = caller_env(),
x_name = NULL,
short_circuit = TRUE,
report_untested = TRUE,
args_cnd = list()
)Arguments
- x
[
any] An object to test.- len, n_null, n_call, n_sym, n_literal, n_invalid
[
numeric()|\(){}|NULL] Possible values for the length, number ofNULLelements, number of 'language' elements, number of 'symbol' elements, number of syntactic literal elements, number of non-syntactic elements. The options of each argument 'arg' are:NULLto not test.A single non-negative number to test for
. == arg. IfInf,. == length(x).A single negative number to test for
. == length(x) + arg.A vector of two non-negative numbers to test for
arg[1] <= . <= arg[2](Infis allowed).A vector of three or more non-negative numbers to test for
. %in% arg.A function that receives the value to test and the length of
x, and returns a singleTRUEorFALSE.
- sentinels
[
character()|NULL] Each entry in this character vector allowsxto also be some scalar sentinel below. Set toNULLto disconsider sentinels."null"forNULL."empty"for any zero-length object."na"for anyNAtype, or"na_logical"forNA,"na_integer"forNA_integer_,"na_real"forNA_real_,"na_complex"forNA_complex_, and"na_character"forNA_character_."nan"forNaN."+inf"for+Inf,"-inf"for-Inf, and"inf"for both."true"/"t"forTRUE, and"false"/"f"forFALSE.
- custom
[
function(x)|NULL] A custom function that takesxas first argument and returns a singleTRUEorFALSE. Set toNULLto not test.- custom_map
[
function(x)|NULL] A custom function that is applied to each element ofx. Must return a singleTRUEorFALSEfor each element. Set toNULLto not test.- action
[
"abort"|"warn"|"inform"] Action to take when the test fails:"abort"to stop execution and throw an error."warning"to issue a warning and returninvisible(x)."message"to issue a message and returninvisible(x).
- env
[
environment()|call()|NULL|missing_arg()] The call to inform as the origin of the error, passed torlang::abort():An environment in the call stack or a hard-coded defused call.
NULLfor no information.missing_arg()to use the assert function itself.The default is
caller_env(), to display the function where the assertion was called.
- x_name
[
character(1)|NULL] The name of the object to use in the error message. IfNULL, the name is inferred from the expression passed tox.- short_circuit
[
TRUE|FALSE] IfTRUE, the tests results will be reported up to the first failure. Else, all tests results are reported. The former is more efficient, while the latter is more informative.- report_untested
[
TRUE|FALSE] IfTRUE, the tests that were not run due to short- circuiting will be reported as untested, else, ignored.- args_cnd
[
list()] Additional arguments passed tocli::cli_abort(),cli::cli_warn(), orcli::cli_inform(), based on the chosenaction.