Validation - Test for one of multiple types
test_multiple.RdThis function checks if x passes at least one of a set of tests. x is
allowed to be any type typeof() in types, and needs to pass the
corresponding test for its type.
For example, if x is of type "integer", then it is tested with
test_integer(). Pass a list of arguments to the test function via ...,
with the same argument name as the type. E.g. integer = list(len = 2).
Arguments
- x
[
any] An object to test.- types
[
character()] A character vector of types to check against.- ...
[
list()each] Lists of arguments to pass to the test function for each type. The list names