Validation - General vectors
test_vector.RdTest if an input is a vector of a given mode (atomic, list, expression, or pairlist) and optionally validate length, missing values, duplicate counts, set inclusion, and ordering constraints.
test_vector() is the predicate test, while assert_vector() validates
its input, aborting if it fails the test.
Usage
test_vector(
x,
mode = "atomic",
len = NULL,
n_na = NULL,
n_null = NULL,
n_empty = NULL,
n_dup = NULL,
sentinels = NULL,
custom = NULL,
custom_map = NULL
)
assert_vector(
x,
mode = "atomic",
len = NULL,
n_na = NULL,
n_null = NULL,
n_empty = NULL,
n_dup = NULL,
sentinels = NULL,
custom = NULL,
custom_map = NULL,
action = "abort",
env = caller_env(),
x_name = NULL,
short_circuit = TRUE,
report_untested = TRUE,
args_cnd = list()
)Arguments
- x
[
any] An object to test.- mode
[
"atomic"|"list"|"expression"|"pairlist"] Allowed vector types. They are additive:"atomic"allows atomic vectors,listallows atomic and lists,expressionallows atomic, lists, and expression objects, andpairlistallows all.- len, n_na, n_null, n_empty, n_dup
[
numeric()|\(){}|NULL] Possible values for the length, number ofNAelements, number ofNULLelements, number of elements with zero length, number of duplicate elements. The options of each argument 'arg' are:NULLto not test.A single non-negative number to test for
. == arg. IfInf,. == length(x).A single negative number to test for
. == length(x) + arg.A vector of two non-negative numbers to test for
arg[1] <= . <= arg[2](Infis allowed).A vector of three or more non-negative numbers to test for
. %in% arg.A function that receives the value to test and the length of
x, and returns a singleTRUEorFALSE.
- sentinels
[
character()|NULL] Each entry in this character vector allowsxto also be some scalar sentinel below. Set toNULLto disconsider sentinels."null"forNULL."empty"for any zero-length object."na"for anyNAtype, or"na_logical"forNA,"na_integer"forNA_integer_,"na_real"forNA_real_,"na_complex"forNA_complex_, and"na_character"forNA_character_."nan"forNaN."+inf"for+Inf,"-inf"for-Inf, and"inf"for both."true"/"t"forTRUE, and"false"/"f"forFALSE.
- custom
[
function(x)|NULL] A custom function that takesxas first argument and returns a singleTRUEorFALSE. Set toNULLto not test.- custom_map
[
function(x)|NULL] A custom function that is applied to each element ofx. Must return a singleTRUEorFALSEfor each element. Set toNULLto not test.- action
[
"abort"|"warn"|"inform"] Action to take when the test fails:"abort"to stop execution and throw an error."warning"to issue a warning and returninvisible(x)."message"to issue a message and returninvisible(x).
- env
[
environment()|call()|NULL|missing_arg()] The call to inform as the origin of the error, passed torlang::abort():An environment in the call stack or a hard-coded defused call.
NULLfor no information.missing_arg()to use the assert function itself.The default is
caller_env(), to display the function where the assertion was called.
- x_name
[
character(1)|NULL] The name of the object to use in the error message. IfNULL, the name is inferred from the expression passed tox.- short_circuit
[
TRUE|FALSE] IfTRUE, the tests results will be reported up to the first failure. Else, all tests results are reported. The former is more efficient, while the latter is more informative.- report_untested
[
TRUE|FALSE] IfTRUE, the tests that were not run due to short- circuiting will be reported as untested, else, ignored.- args_cnd
[
list()] Additional arguments passed tocli::cli_abort(),cli::cli_warn(), orcli::cli_inform(), based on the chosenaction.
Value
[
TRUE|FALSE] fortest_vector().[
=x]invisible(x)forassert_vector(), or aborts if the test fails.
Examples
x <- list(1, 2, NA, 2, NULL)
args <- list(
mode = "list", # Allow atomic vectors and lists (will pass)
len = c(1, 10), # Length must be between 1 and 10 (will pass)
n_na = 0, # No NA values allowed (will fail)
n_null = c(0, 1), # At most 1 NULL element allowed (will pass)
n_empty = 0, # No empty elements allowed (will pass)
n_dup = 0, # No duplicate elements allowed (will fail)
sentinels = c("null"), # Allow NULL x (not the case of x)
custom = NULL, # Not tested
custom_map = \(elt) length(elt) <= 1
# All list elements must have length <= 1 (will pass)
)
do.call(test_vector, c(list(x), args)) #> FALSE (not all tests passed)
#> [1] FALSE
try(do.call(assert_vector, c(list(x), args, short_circuit = FALSE))) #> Error
#> Error in eval(expr, envir) : `x` failed `assert_vector()`:
#> ✔ (pass) sentinels: no sentinel values allowed.
#> ✔ (pass) type : must be of 'type' "list".
#> ✔ (pass) len : length must be in range 1 to 10.
#> ✔ (pass) n_na : #of NA values must be 0.
#> ✔ (pass) n_null: #of NULL values must be in range 0 to 1.
#> ✖ (fail) n_empty: #of empty values must be 0. Was 1.
#> ✖ (fail) n_dup : #of duplicate values must be 0. Was 1.
#> ✔ (pass) custom_map: all elements must pass a custom test.
#>
#> ℹ See `predicater::assert_vector()` and this condition's `rs_assert_error`
#> attribute for details.